"""Contains the URL routes corresponding to different V2 API endpoints."""

EVENT_API = "/2/httpapi"
BATCH_API = "/batch"
CHART_ANNOTATIONS_API = "/annotations"
RELEASES_API = "/release"
